@@ -383,7 +383,7 @@ module_descriptive_ui <- function(id) {
     ),
     fluidRow(
       box(
-        title = "Source Data System",
+        title = "Source Database",
         width = 6,
         fluidRow(
           column(8,
@@ -419,7 +419,7 @@ module_descriptive_ui <- function(id) {
           ))
       ),
       box(
-        title = "Target Data System",
+        title = "Target Database",
         width = 6,
         fluidRow(
           column(8,
